import DatabaseInterface from '../Databases/DatabaseInterface';
import SqlQuery from '../Queries/SqlQuery';
export default class CrudRepository<Model, ValidAttributes = any, PrimaryKeyType = any> {
    protected readonly database: DatabaseInterface;
    protected readonly table: string;
    protected readonly primaryKey: string;
    protected readonly model: new (attributes: Required<ValidAttributes>) => Model;
    protected readonly scope: SqlQuery | null;
    constructor({ database, table, model, primaryKey, scope, }: {
        database: DatabaseInterface;
        table: string;
        primaryKey: string;
        model: new (attributes: Required<ValidAttributes>) => Model;
        scope?: SqlQuery | null;
    });
    get(primaryKeyValue: PrimaryKeyType): Promise<Model>;
    search(where?: SqlQuery | null, orderBy?: SqlQuery | null): Promise<ReadonlyArray<Model>>;
    create(attributes: Required<ValidAttributes>): Promise<Model>;
    update(model: Model, attributes: Partial<ValidAttributes>): Promise<Model>;
    delete(model: Model): Promise<void>;
    protected createModelFromAttributes(attributes: Required<ValidAttributes> | Model): Promise<Model>;
}
